CDL or Common Driver Library
============================
This is a group effort to provide an extended collection of drivers for devices commonly used in FRC.

Drivers
=======
You might ask why there are so few drivers in this library. That is because no one developer can possibly create a driver for every possible sensor for use in FRC, there are just too many.

That is where the community comes in. If you have a device that is not properly represented in wpilib, and that you want to use, why not add a driver here for it?


Authors
=======

- Dustin Spicuzza (dustin@virtualroadside.com)
- Christian Balcom (robot.inventor@gmail.com)
- Insert your name here!
